//---------------------------------------------------------------------------
// Copyright (C) 2001 Dallas Semiconductor Corporation, All Rights Reserved.
// 
// Permission is hereby granted, free of charge, to any person obtaining a 
// copy of this software and associated documentation files (the "Software"), 
// to deal in the Software without restriction, including without limitation 
// the rights to use, copy, modify, merge, publish, distribute, sublicense, 
// and/or sell copies of the Software, and to permit persons to whom the 
// Software is furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included 
// in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF 
// MERCHANTABILITY,  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
// IN NO EVENT SHALL DALLAS SEMICONDUCTOR BE LIABLE FOR ANY CLAIM, DAMAGES 
// OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
// ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
// OTHER DEALINGS IN THE SOFTWARE.
// 
// Except as contained in this notice, the name of Dallas Semiconductor 
// shall not be used except as stated in the Dallas Semiconductor 
// Branding Policy. 
//---------------------------------------------------------------------------

#include <stdio.h>
#include "jibapi.h"

extern BOOL DS2406LEDInit();
extern BOOL DS2406LEDOn();
extern BOOL DS2406LEDOff();

int main(int argc, char* argv[])
{
   char *l_serial[] = { "COM1", "COM2", "COM3", "COM4"};
   LPBYTE l_rom;
   BYTE   l_count, i;
   LPRESPONSEAPDU l_lpResponseAPDU;
   char            l_Buff[256];

   l_count = 0;

   SetJiBSearchParamsEx(4, l_serial, PARALLEL_DS1481 | USB_DS2490);

   l_rom = FindJiBs((LPBYTE)&l_count);

   printf("number found: %d\n", l_count);

   for (i = 0; i < l_count; i++) 
   {
      printf("[%d] %02x %02x %02x %02x %02x %02x %02x %02x\n",
         i, 
         l_rom[0], l_rom[1], l_rom[2], l_rom[3], 
         l_rom[4], l_rom[5], l_rom[6], l_rom[7]);

      SelectJiB(l_rom);
  
      // Get Firmware Version String (just to set adapter and port correctly)
      l_lpResponseAPDU = GetFirmwareVersionString();

      // Find and Turn LED on the same port ON
      if (DS2406LEDInit())
      {
         if (DS2406LEDOn())
            printf("LED is now ON\n");
         else
            printf("ERROR setting LED to ON\n");
      }
      else
         printf("ERROR, could not init LED\n");

      // Get Firmware Version String
      l_lpResponseAPDU = GetFirmwareVersionString();
      if(l_lpResponseAPDU->SW != ERR_ISO_NORMAL_00)
      {
         printf("%s Test Failed with SW = 0x%04hX\n","Firmware Version",l_lpResponseAPDU->SW);
      }
      else
      {
         // trim out the length byte
         memcpy(l_Buff,l_lpResponseAPDU->Data,l_lpResponseAPDU->Len);
         memcpy(l_lpResponseAPDU->Data,l_Buff+1,--(l_lpResponseAPDU->Len));
         // zero terminate the strings
         l_lpResponseAPDU->Data[l_lpResponseAPDU->Len] = 0;
         printf(" Firmware Version String: %s\n",l_lpResponseAPDU->Data);
      }

      // Turn LED on the same port OFF
      if (DS2406LEDOff())
        printf("LED is now OFF\n");
      else
        printf("ERROR, setting LED to OFF\n");
   }

   ReleaseJiBAPIResources();

	return 0;
}

